@@ -83,8 +83,10 @@ def attachSettings(settingsDict, enablePaypal=False):
         'django.contrib.auth.backends.ModelBackend',
         'oscar.apps.customer.auth_backends.EmailBackend',
     ]
+
+    authenticationBackends = tuple(authenticationBackends)
     
-    update(settingsDict, authenticationBackends)
+    extendAuthenticationBackend(settingsDict, authenticationBackends)
     #=========================================================================
     
     #=========================================================================
